@@ -23,7 +23,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.5.2';
+our $VERSION = '3.5.4';
 
 =head1 SYNOPSIS
 
@@ -616,11 +616,11 @@ sub _extract_streaming_urls {
         }
     }
 
-    if (exists $info->{hlsvp}) {
+    if ($info->{livestream} or $info->{live_playback}) {
         if (my @formats = $self->_get_formats_from_ytdl($videoID)) {
             @results = @formats;
         }
-        else {
+        elsif (exists $info->{hlsvp}) {
             push @results,
               {
                 itag => 38,
