@@ -216,7 +216,7 @@ sub format_text {
         DISLIKES    => sub { $self->get_dislikes($info) },
         COMMENTS    => sub { $self->get_comments($info) },
         DURATION    => sub { $self->get_duration($info) },
-        TIME        => sub { $self->format_time($self->get_duration($info)) },
+        TIME        => sub { $self->get_time($info) },
         TITLE       => sub { $self->get_title($info) },
         FTITLE      => sub { $self->normalize_video_title($self->get_title($info), $fat32safe) },
         CAPTION     => sub { $self->get_caption($info) },
@@ -424,6 +424,16 @@ sub get_duration {
     $self->format_duration($info->{contentDetails}{duration});
 }
 
+sub get_time {
+    my ($self, $info) = @_;
+
+    if ($info->{snippet}{liveBroadcastContent} eq 'live') {
+        return 'LIVE';
+    }
+
+    $self->format_time($self->get_duration($info));
+}
+
 sub get_definition {
     my ($self, $info) = @_;
     uc($info->{contentDetails}{definition} // '-');
@@ -491,11 +501,13 @@ sub period_to_date {
     my ($self, $amount, $period) = @_;
 
     state $day   = 60 * 60 * 24;
+    state $week  = $day * 7;
     state $month = $day * 30.4368;
     state $year  = $day * 365.242;
 
     my $time = $amount * (
                             $period =~ /^d/i ? $day
+                          : $period =~ /^w/i ? $week
                           : $period =~ /^m/i ? $month
                           : $period =~ /^y/i ? $year
                           : 0
